"""AppConfig for the marion application"""

from django.apps import AppConfig


class DocumentsConfig(AppConfig):
    """Documents application configuration"""

    default = False
    name = "document"
